==> _PSS_OPENSRC_5_954.zip: _PSS_OPENSRC/_PSS_base/PSM/WhereUsedListView.h <==
#if !defined(AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_)
#define AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// WhereUsedListView.h : header file
//

#include "aplListView.h"
/////////////////////////////////////////////////////////////////////////////
// CWhereUsedListView view

class CWhereUsedListView : public CaplListView
{
protected:
	CWhereUsedListView();           // protected constructor used by dynamic creation
	DECLARE_DYNCREATE(CWhereUsedListView)

// Attributes
public:

// Operations
public:
void UpdateTreeItem(CaplTreeItem *item);

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CWhereUsedListView)
	protected:
	virtual void OnDraw(CDC* pDC);      // overridden to draw this view
	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
	//}}AFX_VIRTUAL

// Implementation
protected:
	virtual ~CWhereUsedListView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// Generated message map functions
protected:
	//{{AFX_MSG(CWhereUsedListView)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_)

==> _PSS_OPENSRC_5_974.zip: _PSS_OPENSRC/_PSS_base/PSM/WhereUsedListView.h <==
#if !defined(AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_)
#define AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// WhereUsedListView.h : header file
//

#include "aplListView.h"
/////////////////////////////////////////////////////////////////////////////
// CWhereUsedListView view

class CWhereUsedListView : public CaplListView
{
protected:
	CWhereUsedListView();           // protected constructor used by dynamic creation
	DECLARE_DYNCREATE(CWhereUsedListView)

// Attributes
public:

	bool m_bLimitShowItems;   //  true,   -  .      .
	int m_iMaxCountShowItems; //      

// Operations
public:
void UpdateTreeItem(CaplTreeItem *item);

	void ResetList(BOOL bShowOneComumn);

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CWhereUsedListView)
	protected:
	virtual void OnDraw(CDC* pDC);      // overridden to draw this view
	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
	//}}AFX_VIRTUAL

// Implementation
protected:
	virtual ~CWhereUsedListView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// Generated message map functions
protected:
	//{{AFX_MSG(CWhereUsedListView)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_WHEREUSEDLISTVIEW_H__4CA783E8_0AE7_417B_8162_1506DE8736B2__INCLUDED_)
